package test;

import org.junit.Test;

public class A {
	@Test
	public void test() {}
}
